# [TestFlows.com Open-Source Software Testing Framework] - Core

**The core module is still work in progress and is currently under development.
Please use it only for reference.**

[TestFlows.com Open-Source Software Testing Framework] Core module.

[TestFlows.com Open-Source Software Testing Framework]: https://testflows.com
